@@ -49,7 +49,6 @@ GET_DATA_DRIFT_DIAGNOSIS_URI = f"{API_VERSION_V2}/project/get_data_drift_diagnos
 GET_PROJECT_CONFIG = f"{API_VERSION_V2}/users/get_xai_config"
 AVAILABLE_TAGS_URI = f"{API_VERSION_V2}/project/get_all_available_tags_info"
 TAG_DATA_URI = f"{API_VERSION_V2}/project/tag_data"
-GET_AVAILABLE_TEXT_MODELS_URI = f"{API_VERSION_V2}/users/get_available_text_models"
 INITIALIZE_TEXT_MODEL_URI = f"{API_VERSION_V2}/users/initalize_text_model"
 GET_FEATURE_IMPORTANCE_URI = f"{API_VERSION_V2}/project/get_feature_importance"
 
@@ -79,6 +78,8 @@ MODEL_SUMMARY_URI = f"{API_VERSION_V2}/project/get_model_perfermance"
 PROJECT_OVERVIEW_TEXT_URI = f"{API_VERSION_V2}/ai-models/project_overview"
 MODEL_SVG_URI = f"{API_VERSION_V2}/project/get_model_svg_plot"
 MODEL_INFERENCES_URI = f"{API_VERSION_V2}/ai-models/get_all_tags_for_models"
+UPLOAD_DATA_PROJECT_URI = f"{API_VERSION_V2}/project/case-register"
+GET_CASE_PROFILE_URI = f"{API_VERSION_V2}/project/get-case-profile"
 
 # Explainability
 GET_CASES_URI = f"{API_VERSION_V2}/ai-models/get_cases"
@@ -97,12 +98,15 @@ GET_OBSERVATIONS_URI = f"{API_VERSION_V2}/observations/get_observations"
 GET_OBSERVATION_PARAMS_URI = f"{API_VERSION_V2}/observations/get_observation_params"
 CREATE_OBSERVATION_URI = f"{API_VERSION_V2}/observations/create_observation"
 UPDATE_OBSERVATION_URI = f"{API_VERSION_V2}/observations/observation_config_update"
+DUPLICATE_OBSERVATION_URI = f"{API_VERSION_V2}/observations/duplicate_observation"
 
 # Policies
 GET_POLICIES_URI = f"{API_VERSION_V2}/policies/get_policies"
 GET_POLICY_PARAMS_URI = f"{API_VERSION_V2}/policies/get_policy_params"
 CREATE_POLICY_URI = f"{API_VERSION_V2}/policies/create_policy"
 UPDATE_POLICY_URI = f"{API_VERSION_V2}/policies/policy_config_update"
+VALIDATE_POLICY_URI = f"{API_VERSION_V2}/policies/validate_policy"
+DUPLICATE_POLICY_URI = f"{API_VERSION_V2}/policies/duplicate_policy"
 
 # Alerts
 GET_TRIGGERS_URI = f"{API_VERSION_V2}/triggers/get_triggers"
@@ -169,4 +173,15 @@ IMAGE_DL = f"{API_VERSION_V2}/evals/"
 
 
 # Agents 
-EXPLAINABILITY_SUMMARY = f"{API_VERSION_V2}/agents/explainability_summary"
\ No newline at end of file
+EXPLAINABILITY_SUMMARY = f"{API_VERSION_V2}/agents/explainability_summary"
+
+#Text
+MESSAGES_URI =  f"sessions/get_session_messages"
+SESSIONS_URI = f"sessions/get_sessions"
+TRACES_URI = f"traces/get_traces"
+GET_GUARDRAILS_URI = f"guardrails/active_guardrails"
+UPDATE_GUARDRAILS_STATUS_URI = f"guardrails/update_guardrail_status"
+DELETE_GUARDRAILS_URI = f"guardrails/delete_guardrail"
+AVAILABLE_GUARDRAILS_URI = f"guardrails/all"
+CONFIGURE_GUARDRAILS_URI = f"guardrails/configure"
+GET_AVAILABLE_TEXT_MODELS_URI = f"{API_VERSION_V2}/users/get_available_text_models"
\ No newline at end of file
